# Go

The Launchable CLI includes built-in integrations for test runners and build tools that are popular in the Golang ecosystem:

* [Bazel](../test-runners/bazel.md)
* [Go Test](../test-runners/go-test.md)

See each integration's page for instructions to add Launchable to your CI pipeline.

